import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range([80, 50]);

export const fruitBowl = (selection, props) => {
  const { fruits, height } = props;
  
  const groups = selection.selectAll('g')
  	.data(fruits);
  const groupsEnter = groups.enter().append('g');
  
  groupsEnter
  	.merge(groups)
  		.attr('transform', (d, i) => 
           `translate(${i * 180 + 100}, ${height / 2})`
      )
  groups.exit()
  	.transition().duration(1000)
  		.attr('transform', 'scale(0, 0)')
    .remove();

  groupsEnter.append('circle')
  	.merge(groups.select('circle'))
      .attr('fill', d => colorScale(d.type))
  		.transition().duration(1000)
      	.attr('r', d => radiusScale(d.type));

  groupsEnter.append('text')
  	.merge(groups.select('text'))
  		.text(d => d.type)
  		.transition().duration(1000)  
  		.attr('y', 120);

}